| cars | R Documentation |
A sample dataset used throughout rsgl documentation and examples
containing attributes for a collection of cars.
Loading rsgl masks datasets::cars; refer to the built-in version as
datasets::cars if you need it.
cars
A data frame with 406 rows and 5 variables:
Integer identifier for the car.
Engine horsepower.
Fuel economy in miles per US gallon.
Country of origin (USA, Europe, Japan).
Model year (1970–1982).
Derived from the cars dataset in the vega-datasets collection
(https://github.com/vega/vega-datasets/blob/main/data/cars.json). The
Miles_per_Gallon, Horsepower, and Origin columns were kept and
renamed, year is the year taken from the original Year date, and
car_id is a row identifier.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.