| avg | R Documentation |
The avg function returns the average of a column
within each group.
avg
The name of a numerical column to average (required).
library(duckdb)
con <- dbConnect(duckdb())
dbWriteTable(con, "cars", cars)
dbGetPlot(con, "
visualize
origin as x,
avg(horsepower) as y
from cars
group by
origin
using bars
")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.