| linear | R Documentation |
The linear scale linearly maps data values to a visual property.
It is the default scale for numerical aesthetic mappings.
linear
The name of an aesthetic to scale (required).
library(duckdb)
con <- dbConnect(duckdb())
dbWriteTable(con, "cars", cars)
# explicit linear scales
dbGetPlot(con, "
visualize
horsepower as x,
miles_per_gallon as y
from cars
using points
scale by
linear(x),
linear(y)
")
# default linear scales
dbGetPlot(con, "
visualize
horsepower as x,
miles_per_gallon as y
from cars
using points
")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.