| points | R Documentation |
Documents the aliases, aesthetics, and qualifiers for the point geom.
point
points
x
y
theta
r
color
size
jittered: adds a small amount of random noise to each point's position.
library(duckdb)
con <- dbConnect(duckdb())
dbWriteTable(con, "cars", cars)
dbGetPlot(con, "
visualize
horsepower as x,
miles_per_gallon as y
from cars
using points
")
set.seed(0)
dbGetPlot(con, "
visualize
origin as x,
miles_per_gallon as y
from cars
using jittered points
")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.